{% extends "admin/base.html" %}
{% load static baton_tags %}
{% load i18n %}

{% block title %}{% if subtitle %}{{ subtitle }} | {% endif %}{{ title }} | {{ site_title|default:_('Django site admin') }}{% endblock title %}

{% block extrahead %}
    <meta content="width=device-width, initial-scale=1.0" name="viewport" />
    <script src="{% static 'baton/app/dist/baton.min.js' %}"></script>
    <!-- <script src="http://localhost:8080/static/baton/app/dist/baton.min.js"></script> -->
    {% baton_config as conf %}
    {{ conf | json_script:"baton-config" }}
    <script src="{% static 'baton/js_snippets/init_baton.js' %}"></script>
{% endblock %}

{% block branding %}
<h1 id="site-name"><a href="{% url 'admin:index' %}">{{ site_header|default:_('Django administration') }}</a></h1>
{% endblock branding %}

{% block nav-global %}{% endblock nav-global %}

{% block footer %}
    {% footer %}
{% endblock footer %}
