// scss-lint:disable IdSelector PlaceholderInExtend NestingDepth QualifyingElement SelectorDepth ImportantRule
body.page-changehistory #content-main {
  @extend .container-fluid;

  > .module {
    @extend .p-3;
    @extend .table-responsive;
    background: $changehistory-bg;
    border: 1px solid $changehistory-border-color;
    margin-top: 15px;

    table {
      @extend .table;
      @extend .table-bordered;
      margin-bottom: 0;

      thead > tr {
        background: $rl-head-bg;
        color: $rl-head-color;
      }

      tbody tr:nth-child(2n + 1) {
        background: $rl-tr-odd-bg;
        color: $rl-tr-odd-color;
      }

      td,
      th {
        padding: .3rem;
      }
    }
  }
}
