html {
  background: $navbar-bg;
  height: 100%;
}

body {
  font-weight: 300;
  min-height: 100%;
  opacity: 0;
  transition: opacity .2s linear;

  &.baton-ready {
    opacity: 1;
  }
}

a {
  text-decoration: none;

  &:hover {
    text-decoration: underline;
  }

  &.btn {
    &:hover {
      text-decoration: none;
    }
  }
}

button,
input,
optgroup,
select,
textarea {
  font-family: $font-family-sans-serif;
}

input[type=checkbox] {
  @extend .form-check-input;
}

.clear {
  clear: both;
}

// remove django 3.1 sidebar
#toggle-nav-sidebar,
#nav-sidebar {
  display: none !important;
}

@keyframes bounce {
  0% { transform: translateY(0) rotate(0deg); }
  100% { transform: translateY(-5px) rotate(5deg); }
}

/* skip to content link */
.skip-to-content-link {
  position: absolute;
  top: -999px;
  margin: 5px;
  padding: 5px;
  z-index: 1;
}

/* hide dark mode switch */
svg.base-svgs {
    display: none;
} 
